lickport_array_interface_python
===============================

This Python package creates a class named LickportArrayInterface.

Authors::

    Peter Polidoro <peter@polidoro.io>

License::

    BSD

